@@ -43,7 +43,7 @@ def parse_arguments():
     """Parse CLI args."""
 
     parser = argparse.ArgumentParser(
-        description="Generate Athena and Spectrum DDL from JSON",
+        description=f"Generate Athena and Spectrum DDL from JSON (v{version})",
     )
 
     parser.set_defaults(partitions=None, mapping=None, type_map=None)
@@ -57,7 +57,7 @@ def parse_arguments():
         dest="infile",
         type=argparse.FileType("r"),
         nargs="+",
-        help="JSON files to convert",
+        help="JSON file(s) to convert",
     )
 
     case_group = parser.add_mutually_exclusive_group()
@@ -78,6 +78,13 @@ def parse_arguments():
         help="DDL: enable case insensitivity and force all fields to lowercase - applied before field lookup in mapping",
     )
 
+    parser.add_argument(
+        "-n",
+        "--numeric_overflow",
+        action="store_true",
+        help="raise exception on numeric overflow",
+    )
+
     parser.add_argument(
         "-d",
         "--infer_date",
@@ -190,7 +197,9 @@ def parse_arguments():
     return args
 
 
-def load_dict_from_infiles(infiles: List[io.TextIOWrapper]) -> Dict:
+def load_dict_from_infiles(
+    infiles: List[io.TextIOWrapper], case_insensitive: bool
+) -> Dict:
     """Load JSON infile(s) as dict | max dict.
     If > 1 files or any input is a list of dicts, max dict is used as schema source.
     """
@@ -202,7 +211,7 @@ def load_dict_from_infiles(infiles: List[io.TextIOWrapper]) -> Dict:
         else:
             infiles[0].seek(0)
 
-    md = MaxDict()
+    md = MaxDict(case_insensitive=case_insensitive)
     for infile in infiles:
         d = json.loads(infile.read())
 
@@ -220,7 +229,7 @@ def create_spectrum_schema():
     """Create Spectrum schema from JSON."""
 
     args = parse_arguments()
-    d = load_dict_from_infiles(args.infile)
+    d = load_dict_from_infiles(args.infile, args.case_insensitive)
 
     kwargs = {k: v for (k, v) in args._get_kwargs()}
     statement = ddl.from_dict(d, **kwargs)
